==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/outputs/PreReleaseAccessRequestSpecResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property city
 * @property companyWebsite
 * @property countryAndRegion
 * @property email
 * @property engagements
 * @property organizationName
 * @property stateOrProvince
 * @property streetAddress
 * @property zipCode
 */
public data class PreReleaseAccessRequestSpecResponse(
    public val city: String? = null,
    public val companyWebsite: String? = null,
    public val countryAndRegion: String? = null,
    public val email: String? = null,
    public val engagements: List<String>? = null,
    public val organizationName: String? = null,
    public val stateOrProvince: String? = null,
    public val streetAddress: String? = null,
    public val zipCode: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.testbase.outputs.PreReleaseAccessRequestSpecResponse):
            PreReleaseAccessRequestSpecResponse = PreReleaseAccessRequestSpecResponse(
            city = javaType.city().map({ args0 -> args0 }).orElse(null),
            companyWebsite = javaType.companyWebsite().map({ args0 -> args0 }).orElse(null),
            countryAndRegion = javaType.countryAndRegion().map({ args0 -> args0 }).orElse(null),
            email = javaType.email().map({ args0 -> args0 }).orElse(null),
            engagements = javaType.engagements().map({ args0 -> args0 }),
            organizationName = javaType.organizationName().map({ args0 -> args0 }).orElse(null),
            stateOrProvince = javaType.stateOrProvince().map({ args0 -> args0 }).orElse(null),
            streetAddress = javaType.streetAddress().map({ args0 -> args0 }).orElse(null),
            zipCode = javaType.zipCode().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/testbase/kotlin/outputs/PreReleaseAccessRequestSpecResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.testbase.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property city
 * @property companyWebsite
 * @property countryAndRegion
 * @property email
 * @property engagements
 * @property organizationName
 * @property stateOrProvince
 * @property streetAddress
 * @property zipCode
 */
public data class PreReleaseAccessRequestSpecResponse(
    public val city: String? = null,
    public val companyWebsite: String? = null,
    public val countryAndRegion: String? = null,
    public val email: String? = null,
    public val engagements: List<String>? = null,
    public val organizationName: String? = null,
    public val stateOrProvince: String? = null,
    public val streetAddress: String? = null,
    public val zipCode: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.testbase.outputs.PreReleaseAccessRequestSpecResponse): PreReleaseAccessRequestSpecResponse = PreReleaseAccessRequestSpecResponse(
            city = javaType.city().map({ args0 -> args0 }).orElse(null),
            companyWebsite = javaType.companyWebsite().map({ args0 -> args0 }).orElse(null),
            countryAndRegion = javaType.countryAndRegion().map({ args0 -> args0 }).orElse(null),
            email = javaType.email().map({ args0 -> args0 }).orElse(null),
            engagements = javaType.engagements().map({ args0 -> args0 }),
            organizationName = javaType.organizationName().map({ args0 -> args0 }).orElse(null),
            stateOrProvince = javaType.stateOrProvince().map({ args0 -> args0 }).orElse(null),
            streetAddress = javaType.streetAddress().map({ args0 -> args0 }).orElse(null),
            zipCode = javaType.zipCode().map({ args0 -> args0 }).orElse(null),
        )
    }
}
